# PDDIansm
A package to detect Potential Drug Drug Interactions (PDDI) according to the French Agency for the Safety of Health Products (ANSM) guidelines. 

## Get started
```bash
pip install pddiansm
```

## Code examples
See [the tutorial](https://github.com/scossin/pddiansm/blob/master/docs/source/index.rst)

## Tests
Run all the tests with this command: 
```bash
python -m unittest discover ./
```